@@ -1,5 +1,5 @@
 package Role::REST::Client::Serializer;
-$Role::REST::Client::Serializer::VERSION = '0.20';
+$Role::REST::Client::Serializer::VERSION = '0.21';
 use Try::Tiny;
 use Moo;
 use Types::Standard qw(Enum InstanceOf);
@@ -61,7 +61,7 @@ sub serialize {
 	try {
 		$result = $self->serializer->serialize($data)
 	} catch {
-		warn "Couldn't serialize data with " . $self->type;
+		warn "Couldn't serialize data with " . $self->type . ": $_";
 	};
 
 	return $result;
@@ -75,7 +75,7 @@ sub deserialize {
 	try {
 		$result = $self->serializer->deserialize($data);
 	} catch {
-		warn "Couldn't deserialize data with " . $self->type;
+		warn "Couldn't deserialize data with " . $self->type . ": $_";
 	};
 
 	return $result;
@@ -95,7 +95,7 @@ Role::REST::Client::Serializer
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 AUTHOR
 
